import React from "react";
import { Typography } from "@material-ui/core";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { IOCDetails } from "./IOCDetails";
import { Link } from 'react-router-dom';
import { LokiContainer } from "../common/Loki/LokiContainer";
import { Alert } from '@material-ui/lab';
import GitRefLink from "./GitRefLink";
import AlertMessages from "./AlertMessages";
import { IOCService } from "./IOCService";
import { IOCCommandTable } from "./IOCCommandTable";
import AccessControl from '../../components/auth/AccessControl';

export function IOCLiveStatus({ ioc, currentCommand, commands, getCommands, buttonDisabled, setButtonDisabled, setOperationQueued, 
  commandLazyParams, setCommandLazyParams, commandColumnSort, setCommandColumnSort, rowsPerPage}) {

  const liveIOC = { ...ioc };
  liveIOC.name = ioc.namingName;
  
  const getSubset = (ioc) => {
    const { description, activeDeployment } = ioc;
    //Show START/STOP components only when IOC was deployed SUCCESSFULLY
    const showControlls = Boolean(activeDeployment) && activeDeployment?.status === 'SUCCESSFUL';

    return ({
      "Git reference": <GitRefLink ioc={ioc} />,
      description,
      "Owner": ioc.owner,
      "Deployed on": 
      <Typography>
        {ioc.activeDeployment?.host.csEntryId ?
          <Link to={`/hosts/${ioc.activeDeployment?.host.csEntryId}`}>{ioc.activeDeployment?.host.fqdn}</Link>
          :
          <>{ioc.activeDeployment?.host.fqdn}</>
        }
      </Typography>,
      "IOC Service Controls": showControlls ? <IOCService ioc={ioc} currentCommand={currentCommand} getCommands={getCommands} 
        buttonDisabled={buttonDisabled} setButtonDisabled={setButtonDisabled} setOperationQueued={setOperationQueued} commandColumnSort={commandColumnSort} commandLazyParams={commandLazyParams}/> : "Can't be controlled, because IOC is not (yet) deployed succesfully",
      /*"Open IOC host in CSentry": <a href={`https://csentry.esss.lu.se/network/hosts/view/${hostName}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${hostName}`}</a>,
      "Host status": status?.toLowerCase(),*/
    })
  };
  
  function isIocDeployed(ioc) {
    return Boolean(ioc.activeDeployment);
  }

  return (
    <>
      <IOCDetails ioc={liveIOC} getSubset={getSubset} alert={<AlertMessages alerts={liveIOC.alerts}/>}/>
      <SimpleAccordion summary="IOC Service Control log">
        <IOCCommandTable commands={commands}
          commandLazyParams={commandLazyParams} setCommandLazyParams={setCommandLazyParams} commandColumnSort={commandColumnSort} setCommandColumnSort={setCommandColumnSort}
          rowsPerPage={rowsPerPage} />
      </SimpleAccordion>
      <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
        renderNoAccess={() => <></>}>
        <SimpleAccordion summary="ProcServLog info" defaultExpanded>
          {liveIOC.activeDeployment?.host.csEntryId ?
            <LokiContainer csEntryId={liveIOC.activeDeployment?.host.csEntryId} iocName={ioc.namingName} isDeployed={isIocDeployed(ioc)} />
            :
            <Alert severity="error" variant="standard">Invalid CSentry ID for target host</Alert>
          }
        </SimpleAccordion>
      </AccessControl>
    </>
  );
}
