import { rest } from 'msw'
import definition from "../test/ccce-api.json";
import OpenAPIBackend from 'openapi-backend';

// create our mock backend with openapi-backend
const api = new OpenAPIBackend({
  definition,
  handlers: {
    validationFail: async (c, res, ctx) => res(ctx.status(400), ctx.json({ err: c.validation.errors })),
    notFound: (c, res, ctx) => res(ctx.status(404)),
    notImplemented: async (c, res, ctx) => {
      console.log("notImplemented handler");
      const { status, mock } = await api.mockResponseForOperation(c.operation.operationId);
      return res(ctx.status(status), ctx.json(mock));
    }
  },
});
api.init();

export const handlers = [
  rest.post('*/login', (req, res, ctx) => {
    console.log('Login request: ' + req);
    return res(
      ctx.json({
        token: 'TOKEN'
      })
    )
  }),
   rest.post('*/renew', (req, res, ctx) => {
    console.log(req);
    return res(
      ctx.json({
        token: 'TOKEN'
      })
    )
  }),
  rest.delete('*/logout', (req, res, ctx) => {
    console.log('Logout request: ' + req);
    return res(
      ctx.json({})
    )
  }),
  rest.get('*/ccce-api', (req, res, ctx) => {
    // This 
    return res(
      ctx.json(definition)
    )
  }),
  rest.get('*/api/v1/*', (req, res, ctx) => {
    console.log('API request: ' + req.url);
    // TODO: fix our traefik setup to remove double /api so this is not necessary
    // Strip out second /api from path when path looks like /api/api/v1/iocs
    const pathname = req.url.pathname ?? "";
    const doctoredPath = pathname.startsWith("/api/api") ? pathname.replace(/^(\/api)/,"") : pathname;
    // the OpenAPIBackend.hanlde request expects a certain form to the input
    // see https://github.com/anttiviljami/openapi-backend/blob/master/DOCS.md#handlerequestreq-handlerargs
    const digested_request = {
      method: req.method,
      path: doctoredPath, // path must not be undefined
      body: req.body,
      query: req.url.search,
      headers: req.headers
    }
    // leave a catch with warning in here for now because it's tricky
    return api.handleRequest(digested_request, res, ctx).catch(x=>console.warn(x))
  }),

]
