import { Container, Grid, Hidden, Paper } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCList } from "../../components/IOC/IOCList";
import { IOCTable } from "../../components/IOC/IOCTable";
import { useIOCSearch } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function IOCListView({user = null}) {
  const [iocs, getIocs, /*reset*/, loading] = useIOCSearch();
  const [query, setQuery] = useState("");
  const classes = useStyles();

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });
  
  const [columnSort, setColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const rowsPerPage = [5, 10, 20, 50, 100];

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams, query, columnSort);

    requestParams.owner = user?.loginName;

    if(columnSort.sortField === "owner") {
      requestParams.orderBy = "OWNER";
    }
  
    if(columnSort.sortField === "namingName") {
      requestParams.orderBy = "IOC_NAME";
    }
  
    if(columnSort.sortField === "sourceVersion") {
      requestParams.orderBy = "GIT_REFERENCE";
    }

    getIocs(requestParams);

  }, [getIocs, user, lazyParams, columnSort, query])

  const title = "Explore IOCs";
  useGlobalAppBar(title);

  let content = (
    <SearchBar search={setQuery} loading={loading}>
      <Hidden smUp>
        <IOCList iocs={iocs.iocList}/>
      </Hidden>
      <Hidden xsDown>
        <IOCTable iocs={iocs.iocList} loading={loading} rowType="explore" 
          lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} totalCount={iocs.totalCount} 
          rowsPerPage={rowsPerPage} />
      </Hidden>
    </SearchBar>
  );

  return (
    <RootContainer>
      <Container>
        <Paper className={classes.root}>
          <Grid container spacing={1}>
            <Grid item xs={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
    </RootContainer>
  );
}

