import React, { useState, useEffect } from "react";
import {
    Paper,
    Grid,
    Hidden,
    Container
} from '@material-ui/core';
import { RootContainer } from "../../components/common/Container/RootContainer";
import { HostList } from '../../components/host/HostList';
import { HostTable } from '../../components/host/HostTable';
import { useCSEntrySearch } from "../../api/SwaggerApi";
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function HostListView() {
    useGlobalAppBar("Explore IOC hosts");

    const [hosts, getHosts, /*reset*/, loading] = useCSEntrySearch();
    const [query, setQuery] = useState("");
    const classes = useStyles();

    const [lazyParams, setLazyParams] = useState({
        first: 0,
        rows: 10,
        page: 0
      });
      
      const [columnSort, setColumnSort] = useState({
        sortField: null,
        sortOrder: null
      });

      const rowsPerPage = [5, 10, 20, 50];

    useEffect(() => {
        
        let requestParams = initRequestParams(lazyParams, query, columnSort);

        getHosts(requestParams);
    }, [getHosts, lazyParams, query, columnSort])
   
    const content = (
        <>
        <SearchBar search={setQuery} loading={loading}>
            <Hidden smUp>
                <HostList hosts={hosts.hostList}/>
            </Hidden>
            <Hidden xsDown>
                <HostTable hosts={hosts.hostList} loading={loading}
                    totalCount={hosts.totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
                    rowsPerPage={rowsPerPage} />
            </Hidden>
        </SearchBar>
        </>
    );

    return (
        <RootContainer>
            <Container>
                <Paper className={classes.root}>
                    <Grid container spacing={1} justify="flex-end">
                        <Grid item xs={12} md={12}>
                            {content}
                        </Grid>
                    </Grid>
                </Paper>
            </Container>
        </RootContainer>
    );
}